function PlotGraph(points,A,titlestring)
% displays non-weighted similarity graph (all points with non-zero similarity are connected)
%
% Input: 
% points = coordinates of points in 2D space (size(num_points,2))
% A = incidence matrix (size(num_points,num_points)), must bge symmetric,
% square
% titlestring = title of the graph 

num_points = size(A,1); 

if (size(A,1) ~= size(A, 2)), 
  error('Incidence matrix is not square. ')
end

if (sum(sum(A - A') > 0.0001)), 
  warning('Incidence matrix is not symmetric. Only one orientation will be used.')
end

if (size(points,1) ~= num_points)
  error('Number of data points does not match the dimension of the incidence matrix.' )
end


clf
hold all
plot(points(:,1), points(:,2), 'bx');


% draws edges: 
xx = zeros(2*num_points,1);
yy = zeros(2*num_points,1);
DiffVal=0; NumDiffVal=0;

for it= 1: num_points
  indices = find(A(it,:)>0);
  NumIndices=length(indices);
  if(NumIndices>0)
    xx(1:2:2*NumIndices)=points(it,1);
    xx(2:2:2*NumIndices)=points(indices,1);
    yy(1:2:2*NumIndices)=points(it,2);
    yy(2:2:2*NumIndices)=points(indices,2);
    plot(xx(1:2*NumIndices),yy(1:2*NumIndices),'-r');
  end    
end

title(titlestring)
axis tight


